// Copyright 2021 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * Name of the chrome flags.
 */
export enum Flag {
  LOW_STORAGE_WARNING = 'lowStorageWarning',
  TIME_LAPSE = 'timeLapse',
}
